@@ -6,16 +6,13 @@ from StructNoSQL.practical_logger import message_with_vars
 from StructNoSQL.query import Query
 
 
-class TableDataModel:
-    pass
-
 class BaseDataModel:
     def __init__(self):
         self.childrens_map: Optional[dict] = None
 
 class MapModel(BaseDataModel):
     _default_primitive_type = dict
-    _num_required_fields = 0
+    required_fields: list = None
 
     def __init__(self, **kwargs):
         super().__init__()
@@ -30,9 +27,10 @@ class MapModel(BaseDataModel):
     def dict(self) -> dict:
         return self.childrens_map if self.childrens_map is not None else self.kwargs
 
-    @property
-    def num_required_fields(self) -> int:
-        return self._num_required_fields
+class TableDataModel(MapModel):
+    # The TableDataModel inherit from MapModel, to allow easier validation of record data.
+    # For example, when the put_record function is used, and needs data validation.
+    pass
 
 
 class BaseItem:
@@ -51,7 +49,7 @@ class BaseItem:
         self._query = None
 
         self.map_key_expected_type: Optional[type] = None
-        self.map_model: Optional[MapModel] = None
+        self.map_model: Optional[MapModel or type] = None
 
         self._custom_default_value = custom_default_value
         self._field_type = field_type
@@ -67,14 +65,14 @@ class BaseItem:
 
                 if alias_variable_name == "Dict":
                     self._field_type = dict
+                    self._default_field_type = dict
                     self._dict_key_expected_type = alias_args[0]
                     self._dict_items_excepted_type = alias_args[1]
 
                 elif alias_variable_name == "List":
                     raise Exception(f"List not yet implemented.")
 
-
-    def validate_data(self, load_data_into_objects: bool) -> Optional[Any]:
+    def validate_data(self, load_data_into_objects: bool = False) -> Tuple[Optional[Any], bool]:
         from StructNoSQL.validator import validate_data
         validated_data, valid = validate_data(
             value=self._value, item_type_to_return_to=self, load_data_into_objects=load_data_into_objects,
